Class: Google::Apis::CloudfunctionsV2beta::BuildConfigOverrides

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudfunctions_v2beta/classes.rb,
lib/google/apis/cloudfunctions_v2beta/representations.rb,
lib/google/apis/cloudfunctions_v2beta/representations.rb

Overview

Contains overrides related to the function's build configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BuildConfigOverrides

Returns a new instance of BuildConfigOverrides.



362
363
364
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 362

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#runtimeString

Optional. Specifies the desired runtime for the new Cloud Run function. (e.g., "nodejs20", "python312"). Constraints: 1. This field CANNOT be used to change the runtime language (e.g., from NODEJS to PYTHON). The backend will enforce this. 2. This field can ONLY be used to upgrade the runtime version (e.g., nodejs18 to nodejs20). Downgrading the version is not permitted. The backend will validate the version change. If provided and valid, this overrides the runtime of the Gen1 function. Corresponds to the JSON property runtime

Returns:

  • (String)


360
361
362
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 360

def runtime
  @runtime
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



367
368
369
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 367

def update!(**args)
  @runtime = args[:runtime] if args.key?(:runtime)
end