Class: Google::Apis::CloudfunctionsV2beta::CloudFunctionsService
- Inherits:
-
Google::Apis::Core::BaseService
- Object
- Google::Apis::Core::BaseService
- Google::Apis::CloudfunctionsV2beta::CloudFunctionsService
- Defined in:
- lib/google/apis/cloudfunctions_v2beta/service.rb
Overview
Cloud Functions API
Manages lightweight user-provided functions executed in response to events.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://cloudfunctions.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#abort_function_upgrade(name, abort_function_upgrade_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation
Aborts generation upgrade process for a function with the given name from the specified project.
-
#commit_function_upgrade(name, commit_function_upgrade_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation
Finalizes the upgrade after which function upgrade can not be rolled back.
-
#commit_function_upgrade_as_gen2(name, commit_function_upgrade_as_gen2_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation
Commits a function upgrade from GCF Gen1 to GCF Gen2.
-
#create_project_location_function(parent, function_object = nil, function_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation
Creates a new function.
-
#delete_project_location_function(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation
Deletes a function with the given name from the specified project.
-
#detach_function(name, detach_function_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation
Detaches 2nd Gen function to Cloud Run function.
-
#generate_function_download_url(name, generate_download_url_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::GenerateDownloadUrlResponse
Returns a signed URL for downloading deployed function source code.
-
#generate_function_upload_url(parent, generate_upload_url_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::GenerateUploadUrlResponse
Returns a signed URL for uploading a function source code.
-
#get_project_location_function(name, revision: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Function
Returns a function with the given name from the requested project.
-
#get_project_location_function_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Policy
Gets the access control policy for a resource.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation
Gets the latest state of a long-running operation.
-
#initialize ⇒ CloudFunctionsService
constructor
A new instance of CloudFunctionsService.
-
#list_project_location_functions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::ListFunctionsResponse
Returns a list of functions that belong to the requested project.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_runtimes(parent, filter: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::ListRuntimesResponse
Returns a list of runtimes that are supported for the requested project.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_function(name, function_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation
Updates existing function.
-
#redirect_function_upgrade_traffic(name, redirect_function_upgrade_traffic_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation
Changes the traffic target of a function from the original 1st Gen function to the 2nd Gen copy.
-
#rollback_function_upgrade_traffic(name, rollback_function_upgrade_traffic_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation
Reverts the traffic target of a function from the 2nd Gen copy to the original 1st Gen function.
-
#set_function_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Policy
Sets the access control policy on the specified resource.
-
#setup_function_upgrade_config(name, setup_function_upgrade_config_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation
Creates a 2nd Gen copy of the function configuration based on the 1st Gen function with the given name.
-
#test_function_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
Constructor Details
#initialize ⇒ CloudFunctionsService
Returns a new instance of CloudFunctionsService.
47 48 49 50 51 52 |
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-cloudfunctions_v2beta', client_version: Google::Apis::CloudfunctionsV2beta::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#abort_function_upgrade(name, abort_function_upgrade_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation
Aborts generation upgrade process for a function with the given name from the specified project. Deletes all 2nd Gen copy related configuration and resources which were created during the upgrade process.
133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 133 def abort_function_upgrade(name, abort_function_upgrade_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta/{+name}:abortFunctionUpgrade', ) command.request_representation = Google::Apis::CloudfunctionsV2beta::AbortFunctionUpgradeRequest::Representation command.request_object = abort_function_upgrade_request_object command.response_representation = Google::Apis::CloudfunctionsV2beta::Operation::Representation command.response_class = Google::Apis::CloudfunctionsV2beta::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#commit_function_upgrade(name, commit_function_upgrade_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation
Finalizes the upgrade after which function upgrade can not be rolled back. This is the last step of the multi step process to upgrade 1st Gen functions to 2nd Gen. Deletes all original 1st Gen related configuration and resources.
168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 168 def commit_function_upgrade(name, commit_function_upgrade_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta/{+name}:commitFunctionUpgrade', ) command.request_representation = Google::Apis::CloudfunctionsV2beta::CommitFunctionUpgradeRequest::Representation command.request_object = commit_function_upgrade_request_object command.response_representation = Google::Apis::CloudfunctionsV2beta::Operation::Representation command.response_class = Google::Apis::CloudfunctionsV2beta::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#commit_function_upgrade_as_gen2(name, commit_function_upgrade_as_gen2_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation
Commits a function upgrade from GCF Gen1 to GCF Gen2. This action deletes the Gen1 function, leaving the Gen2 function active and manageable by the GCFv2 API.
204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 204 def commit_function_upgrade_as_gen2(name, commit_function_upgrade_as_gen2_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta/{+name}:commitFunctionUpgradeAsGen2', ) command.request_representation = Google::Apis::CloudfunctionsV2beta::CommitFunctionUpgradeAsGen2Request::Representation command.request_object = commit_function_upgrade_as_gen2_request_object command.response_representation = Google::Apis::CloudfunctionsV2beta::Operation::Representation command.response_class = Google::Apis::CloudfunctionsV2beta::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_function(parent, function_object = nil, function_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation
Creates a new function. If a function with the given name already exists in
the specified project, the long running operation will return ALREADY_EXISTS
error.
244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 244 def create_project_location_function(parent, function_object = nil, function_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta/{+parent}/functions', ) command.request_representation = Google::Apis::CloudfunctionsV2beta::Function::Representation command.request_object = function_object command.response_representation = Google::Apis::CloudfunctionsV2beta::Operation::Representation command.response_class = Google::Apis::CloudfunctionsV2beta::Operation command.params['parent'] = parent unless parent.nil? command.query['functionId'] = function_id unless function_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_function(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation
Deletes a function with the given name from the specified project. If the given function is used by some trigger, the trigger will be updated to remove this function.
279 280 281 282 283 284 285 286 287 |
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 279 def delete_project_location_function(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2beta/{+name}', ) command.response_representation = Google::Apis::CloudfunctionsV2beta::Operation::Representation command.response_class = Google::Apis::CloudfunctionsV2beta::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#detach_function(name, detach_function_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation
Detaches 2nd Gen function to Cloud Run function.
310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 310 def detach_function(name, detach_function_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta/{+name}:detachFunction', ) command.request_representation = Google::Apis::CloudfunctionsV2beta::DetachFunctionRequest::Representation command.request_object = detach_function_request_object command.response_representation = Google::Apis::CloudfunctionsV2beta::Operation::Representation command.response_class = Google::Apis::CloudfunctionsV2beta::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#generate_function_download_url(name, generate_download_url_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::GenerateDownloadUrlResponse
Returns a signed URL for downloading deployed function source code. The URL is only valid for a limited period and should be used within 30 minutes of generation. For more information about the signed URL usage see: https://cloud. google.com/storage/docs/access-control/signed-urls
347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 347 def generate_function_download_url(name, generate_download_url_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta/{+name}:generateDownloadUrl', ) command.request_representation = Google::Apis::CloudfunctionsV2beta::GenerateDownloadUrlRequest::Representation command.request_object = generate_download_url_request_object command.response_representation = Google::Apis::CloudfunctionsV2beta::GenerateDownloadUrlResponse::Representation command.response_class = Google::Apis::CloudfunctionsV2beta::GenerateDownloadUrlResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#generate_function_upload_url(parent, generate_upload_url_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::GenerateUploadUrlResponse
Returns a signed URL for uploading a function source code. For more
information about the signed URL usage see: https://cloud.google.com/storage/
docs/access-control/signed-urls. Once the function source code upload is
complete, the used signed URL should be provided in CreateFunction or
UpdateFunction request as a reference to the function source code. When
uploading source code to the generated signed URL, please follow these
restrictions: * Source file type should be a zip file. * No credentials should
be attached - the signed URLs provide access to the target bucket using
internal service identity; if credentials were attached, the identity from the
credentials would be used, but that identity does not have permissions to
upload files to the URL. When making a HTTP PUT request, specify this header: *
content-type: application/zip Do not specify this header: * Authorization:
Bearer YOUR_TOKEN
393 394 395 396 397 398 399 400 401 402 403 |
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 393 def generate_function_upload_url(parent, generate_upload_url_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta/{+parent}/functions:generateUploadUrl', ) command.request_representation = Google::Apis::CloudfunctionsV2beta::GenerateUploadUrlRequest::Representation command.request_object = generate_upload_url_request_object command.response_representation = Google::Apis::CloudfunctionsV2beta::GenerateUploadUrlResponse::Representation command.response_class = Google::Apis::CloudfunctionsV2beta::GenerateUploadUrlResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_function(name, revision: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Function
Returns a function with the given name from the requested project.
431 432 433 434 435 436 437 438 439 440 |
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 431 def get_project_location_function(name, revision: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta/{+name}', ) command.response_representation = Google::Apis::CloudfunctionsV2beta::Function::Representation command.response_class = Google::Apis::CloudfunctionsV2beta::Function command.params['name'] = name unless name.nil? command.query['revision'] = revision unless revision.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_function_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
476 477 478 479 480 481 482 483 484 485 |
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 476 def get_project_location_function_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::CloudfunctionsV2beta::Policy::Representation command.response_class = Google::Apis::CloudfunctionsV2beta::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
787 788 789 790 791 792 793 794 795 |
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 787 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta/{+name}', ) command.response_representation = Google::Apis::CloudfunctionsV2beta::Operation::Representation command.response_class = Google::Apis::CloudfunctionsV2beta::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_functions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::ListFunctionsResponse
Returns a list of functions that belong to the requested project.
528 529 530 531 532 533 534 535 536 537 538 539 540 |
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 528 def list_project_location_functions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta/{+parent}/functions', ) command.response_representation = Google::Apis::CloudfunctionsV2beta::ListFunctionsResponse::Representation command.response_class = Google::Apis::CloudfunctionsV2beta::ListFunctionsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
832 833 834 835 836 837 838 839 840 841 842 843 844 |
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 832 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta/{+name}/operations', ) command.response_representation = Google::Apis::CloudfunctionsV2beta::ListOperationsResponse::Representation command.response_class = Google::Apis::CloudfunctionsV2beta::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_runtimes(parent, filter: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::ListRuntimesResponse
Returns a list of runtimes that are supported for the requested project.
870 871 872 873 874 875 876 877 878 879 |
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 870 def list_project_location_runtimes(parent, filter: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta/{+parent}/runtimes', ) command.response_representation = Google::Apis::CloudfunctionsV2beta::ListRuntimesResponse::Representation command.response_class = Google::Apis::CloudfunctionsV2beta::ListRuntimesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the [
ListLocationsRequest.name] field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 96 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta/{+name}/locations', ) command.response_representation = Google::Apis::CloudfunctionsV2beta::ListLocationsResponse::Representation command.response_class = Google::Apis::CloudfunctionsV2beta::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_function(name, function_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation
Updates existing function.
567 568 569 570 571 572 573 574 575 576 577 578 |
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 567 def patch_project_location_function(name, function_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v2beta/{+name}', ) command.request_representation = Google::Apis::CloudfunctionsV2beta::Function::Representation command.request_object = function_object command.response_representation = Google::Apis::CloudfunctionsV2beta::Operation::Representation command.response_class = Google::Apis::CloudfunctionsV2beta::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#redirect_function_upgrade_traffic(name, redirect_function_upgrade_traffic_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation
Changes the traffic target of a function from the original 1st Gen function to the 2nd Gen copy. This is the second step of the multi step process to upgrade 1st Gen functions to 2nd Gen. After this operation, all new traffic will be served by 2nd Gen copy.
605 606 607 608 609 610 611 612 613 614 615 |
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 605 def redirect_function_upgrade_traffic(name, redirect_function_upgrade_traffic_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta/{+name}:redirectFunctionUpgradeTraffic', ) command.request_representation = Google::Apis::CloudfunctionsV2beta::RedirectFunctionUpgradeTrafficRequest::Representation command.request_object = redirect_function_upgrade_traffic_request_object command.response_representation = Google::Apis::CloudfunctionsV2beta::Operation::Representation command.response_class = Google::Apis::CloudfunctionsV2beta::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#rollback_function_upgrade_traffic(name, rollback_function_upgrade_traffic_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation
Reverts the traffic target of a function from the 2nd Gen copy to the original 1st Gen function. After this operation, all new traffic would be served by the 1st Gen.
641 642 643 644 645 646 647 648 649 650 651 |
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 641 def rollback_function_upgrade_traffic(name, rollback_function_upgrade_traffic_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta/{+name}:rollbackFunctionUpgradeTraffic', ) command.request_representation = Google::Apis::CloudfunctionsV2beta::RollbackFunctionUpgradeTrafficRequest::Representation command.request_object = rollback_function_upgrade_traffic_request_object command.response_representation = Google::Apis::CloudfunctionsV2beta::Operation::Representation command.response_class = Google::Apis::CloudfunctionsV2beta::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_function_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
678 679 680 681 682 683 684 685 686 687 688 |
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 678 def set_function_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::CloudfunctionsV2beta::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::CloudfunctionsV2beta::Policy::Representation command.response_class = Google::Apis::CloudfunctionsV2beta::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#setup_function_upgrade_config(name, setup_function_upgrade_config_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation
Creates a 2nd Gen copy of the function configuration based on the 1st Gen function with the given name. This is the first step of the multi step process to upgrade 1st Gen functions to 2nd Gen. Only 2nd Gen configuration is setup as part of this request and traffic continues to be served by 1st Gen.
715 716 717 718 719 720 721 722 723 724 725 |
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 715 def setup_function_upgrade_config(name, setup_function_upgrade_config_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta/{+name}:setupFunctionUpgradeConfig', ) command.request_representation = Google::Apis::CloudfunctionsV2beta::SetupFunctionUpgradeConfigRequest::Representation command.request_object = setup_function_upgrade_config_request_object command.response_representation = Google::Apis::CloudfunctionsV2beta::Operation::Representation command.response_class = Google::Apis::CloudfunctionsV2beta::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_function_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
754 755 756 757 758 759 760 761 762 763 764 |
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 754 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::CloudfunctionsV2beta::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::CloudfunctionsV2beta::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::CloudfunctionsV2beta::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |