Class: Google::Apis::CloudfunctionsV2beta::DirectVpcNetworkInterface

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudfunctions_v2beta/classes.rb,
lib/google/apis/cloudfunctions_v2beta/representations.rb,
lib/google/apis/cloudfunctions_v2beta/representations.rb

Overview

The Direct VPC network interface. This is mutually exclusive with VPC Connector.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DirectVpcNetworkInterface

Returns a new instance of DirectVpcNetworkInterface.



478
479
480
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 478

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#networkString

Optional. The name of the VPC network to which the function will be connected. Specify either a VPC network or a subnet, or both. If you specify only a network, the subnet uses the same name as the network. Corresponds to the JSON property network

Returns:

  • (String)


462
463
464
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 462

def network
  @network
end

#subnetworkString

Optional. The name of the VPC subnetwork that the Cloud Function resource will get IPs from. Specify either a VPC network or a subnet, or both. If both network and subnetwork are specified, the given VPC subnetwork must belong to the given VPC network. If subnetwork is not specified, the subnetwork with the same name with the network will be used. Corresponds to the JSON property subnetwork

Returns:

  • (String)


471
472
473
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 471

def subnetwork
  @subnetwork
end

#tagsArray<String>

Optional. Network tags applied to this Cloud Function resource. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


476
477
478
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 476

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



483
484
485
486
487
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 483

def update!(**args)
  @network = args[:network] if args.key?(:network)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @tags = args[:tags] if args.key?(:tags)
end