Class: Google::Apis::CloudfunctionsV2beta::EventTrigger

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudfunctions_v2beta/classes.rb,
lib/google/apis/cloudfunctions_v2beta/representations.rb,
lib/google/apis/cloudfunctions_v2beta/representations.rb

Overview

Describes EventTrigger, used to request events to be sent from another service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EventTrigger

Returns a new instance of EventTrigger.



592
593
594
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 592

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#channelString

Optional. The name of the channel associated with the trigger in projects/ project/locations/location/channels/channel`format. You must provide a channel to receive events from Eventarc SaaS partners. Corresponds to the JSON propertychannel`

Returns:

  • (String)


533
534
535
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 533

def channel
  @channel
end

#event_filtersArray<Google::Apis::CloudfunctionsV2beta::EventFilter>

Criteria used to filter events. Corresponds to the JSON property eventFilters



538
539
540
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 538

def event_filters
  @event_filters
end

#event_typeString

Required. The type of event to observe. For example: google.cloud.audit.log. v1.written or google.cloud.pubsub.topic.v1.messagePublished. Corresponds to the JSON property eventType

Returns:

  • (String)


544
545
546
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 544

def event_type
  @event_type
end

#pubsub_topicString

Optional. The name of a Pub/Sub topic in the same project that will be used as the transport topic for the event delivery. Format: projects/project/topics/ topic`. This is only valid for events of typegoogle.cloud.pubsub.topic.v1. messagePublished. The topic provided here will not be deleted at function deletion. Corresponds to the JSON propertypubsubTopic`

Returns:

  • (String)


553
554
555
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 553

def pubsub_topic
  @pubsub_topic
end

#retry_policyString

Optional. If unset, then defaults to ignoring failures (i.e. not retrying them) . Corresponds to the JSON property retryPolicy

Returns:

  • (String)


559
560
561
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 559

def retry_policy
  @retry_policy
end

#serviceString

Optional. The hostname of the service that 1st Gen function should be observed. If no string is provided, the default service implementing the API will be used. For example, storage.googleapis.com is the default for all event types in the google.storage namespace. The field is only applicable to 1st Gen functions. Corresponds to the JSON property service

Returns:

  • (String)


568
569
570
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 568

def service
  @service
end

#service_account_emailString

Optional. The email of the trigger's service account. The service account must have permission to invoke Cloud Run services, the permission is run.routes. invoke. If empty, defaults to the Compute Engine default service account: ` project_number-compute@developer.gserviceaccount.com. Corresponds to the JSON propertyserviceAccountEmail`

Returns:

  • (String)


576
577
578
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 576

def 
  @service_account_email
end

#triggerString

Output only. The resource name of the Eventarc trigger. The format of this field is projects/project/locations/region/triggers/trigger`. Corresponds to the JSON propertytrigger`

Returns:

  • (String)


582
583
584
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 582

def trigger
  @trigger
end

#trigger_regionString

The region that the trigger will be in. The trigger will only receive events originating in this region. It can be the same region as the function, a different region or multi-region, or the global region. If not provided, defaults to the same region as the function. Corresponds to the JSON property triggerRegion

Returns:

  • (String)


590
591
592
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 590

def trigger_region
  @trigger_region
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



597
598
599
600
601
602
603
604
605
606
607
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 597

def update!(**args)
  @channel = args[:channel] if args.key?(:channel)
  @event_filters = args[:event_filters] if args.key?(:event_filters)
  @event_type = args[:event_type] if args.key?(:event_type)
  @pubsub_topic = args[:pubsub_topic] if args.key?(:pubsub_topic)
  @retry_policy = args[:retry_policy] if args.key?(:retry_policy)
  @service = args[:service] if args.key?(:service)
  @service_account_email = args[:service_account_email] if args.key?(:service_account_email)
  @trigger = args[:trigger] if args.key?(:trigger)
  @trigger_region = args[:trigger_region] if args.key?(:trigger_region)
end