Class: Google::Apis::CloudfunctionsV2beta::GenerateUploadUrlRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudfunctions_v2beta/classes.rb,
lib/google/apis/cloudfunctions_v2beta/representations.rb,
lib/google/apis/cloudfunctions_v2beta/representations.rb

Overview

Request of GenerateSourceUploadUrl method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenerateUploadUrlRequest

Returns a new instance of GenerateUploadUrlRequest.



842
843
844
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 842

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#environmentString

The function environment the generated upload url will be used for. The upload url for 2nd Gen functions can also be used for 1st gen functions, but not vice versa. If not specified, 2nd generation-style upload URLs are generated. Corresponds to the JSON property environment

Returns:

  • (String)


825
826
827
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 825

def environment
  @environment
end

#kms_key_nameString

Resource name of a KMS crypto key (managed by the user) used to encrypt/ decrypt function source code objects in intermediate Cloud Storage buckets. When you generate an upload url and upload your source code, it gets copied to an intermediate Cloud Storage bucket. The source code is then copied to a versioned directory in the sources bucket in the consumer project during the function deployment. It must match the pattern projects/project/locations/ location/keyRings/key_ring/cryptoKeys/crypto_key`. The Google Cloud Functions service account (service-project_number@gcf-admin-robot.iam. gserviceaccount.com) must be granted the role 'Cloud KMS CryptoKey Encrypter/ Decrypter (roles/cloudkms.cryptoKeyEncrypterDecrypter)' on the Key/KeyRing/ Project/Organization (least access preferred). Corresponds to the JSON propertykmsKeyName`

Returns:

  • (String)


840
841
842
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 840

def kms_key_name
  @kms_key_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



847
848
849
850
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 847

def update!(**args)
  @environment = args[:environment] if args.key?(:environment)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
end