Class: Google::Apis::CloudfunctionsV2beta::RepoSource
- Inherits:
-
Object
- Object
- Google::Apis::CloudfunctionsV2beta::RepoSource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudfunctions_v2beta/classes.rb,
lib/google/apis/cloudfunctions_v2beta/representations.rb,
lib/google/apis/cloudfunctions_v2beta/representations.rb
Overview
Location of the source in a Google Cloud Source Repository.
Instance Attribute Summary collapse
-
#branch_name ⇒ String
Regex matching branches to build.
-
#commit_sha ⇒ String
Explicit commit SHA to build.
-
#dir ⇒ String
Directory, relative to the source root, in which to run the build.
-
#project_id ⇒ String
ID of the project that owns the Cloud Source Repository.
-
#repo_name ⇒ String
Name of the Cloud Source Repository.
-
#tag_name ⇒ String
Regex matching tags to build.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RepoSource
constructor
A new instance of RepoSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RepoSource
Returns a new instance of RepoSource.
1532 1533 1534 |
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 1532 def initialize(**args) update!(**args) end |
Instance Attribute Details
#branch_name ⇒ String
Regex matching branches to build. The syntax of the regular expressions
accepted is the syntax accepted by RE2 and described at https://github.com/
google/re2/wiki/Syntax
Corresponds to the JSON property branchName
1499 1500 1501 |
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 1499 def branch_name @branch_name end |
#commit_sha ⇒ String
Explicit commit SHA to build.
Corresponds to the JSON property commitSha
1504 1505 1506 |
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 1504 def commit_sha @commit_sha end |
#dir ⇒ String
Directory, relative to the source root, in which to run the build. This must
be a relative path. If a step's dir is specified and is an absolute path,
this value is ignored for that step's execution. eg. helloworld (no leading
slash allowed)
Corresponds to the JSON property dir
1512 1513 1514 |
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 1512 def dir @dir end |
#project_id ⇒ String
ID of the project that owns the Cloud Source Repository. If omitted, the
project ID requesting the build is assumed.
Corresponds to the JSON property projectId
1518 1519 1520 |
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 1518 def project_id @project_id end |
#repo_name ⇒ String
Name of the Cloud Source Repository.
Corresponds to the JSON property repoName
1523 1524 1525 |
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 1523 def repo_name @repo_name end |
#tag_name ⇒ String
Regex matching tags to build. The syntax of the regular expressions accepted
is the syntax accepted by RE2 and described at https://github.com/google/re2/
wiki/Syntax
Corresponds to the JSON property tagName
1530 1531 1532 |
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 1530 def tag_name @tag_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1537 1538 1539 1540 1541 1542 1543 1544 |
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 1537 def update!(**args) @branch_name = args[:branch_name] if args.key?(:branch_name) @commit_sha = args[:commit_sha] if args.key?(:commit_sha) @dir = args[:dir] if args.key?(:dir) @project_id = args[:project_id] if args.key?(:project_id) @repo_name = args[:repo_name] if args.key?(:repo_name) @tag_name = args[:tag_name] if args.key?(:tag_name) end |