Class: Google::Apis::CloudfunctionsV2beta::SetupFunctionUpgradeConfigRequest
- Inherits:
-
Object
- Object
- Google::Apis::CloudfunctionsV2beta::SetupFunctionUpgradeConfigRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudfunctions_v2beta/classes.rb,
lib/google/apis/cloudfunctions_v2beta/representations.rb,
lib/google/apis/cloudfunctions_v2beta/representations.rb
Overview
Request for the SetupFunctionUpgradeConfig method.
Instance Attribute Summary collapse
-
#build_config_overrides ⇒ Google::Apis::CloudfunctionsV2beta::BuildConfigOverrides
Contains overrides related to the function's build configuration.
-
#service_config_overrides ⇒ Google::Apis::CloudfunctionsV2beta::ServiceConfigOverrides
Contains overrides related to the function's service configuration.
-
#trigger_service_account ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetupFunctionUpgradeConfigRequest
constructor
A new instance of SetupFunctionUpgradeConfigRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetupFunctionUpgradeConfigRequest
Returns a new instance of SetupFunctionUpgradeConfigRequest.
2020 2021 2022 |
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 2020 def initialize(**args) update!(**args) end |
Instance Attribute Details
#build_config_overrides ⇒ Google::Apis::CloudfunctionsV2beta::BuildConfigOverrides
Contains overrides related to the function's build configuration.
Corresponds to the JSON property buildConfigOverrides
2005 2006 2007 |
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 2005 def build_config_overrides @build_config_overrides end |
#service_config_overrides ⇒ Google::Apis::CloudfunctionsV2beta::ServiceConfigOverrides
Contains overrides related to the function's service configuration.
Corresponds to the JSON property serviceConfigOverrides
2010 2011 2012 |
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 2010 def service_config_overrides @service_config_overrides end |
#trigger_service_account ⇒ String
Optional. The trigger's service account. The service account must have
permission to invoke Cloud Run services, the permission is run.routes.invoke.
If empty, defaults to the Compute Engine default service account: `
project_number-compute@developer.gserviceaccount.com.
Corresponds to the JSON propertytriggerServiceAccount`
2018 2019 2020 |
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 2018 def trigger_service_account @trigger_service_account end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2025 2026 2027 2028 2029 |
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 2025 def update!(**args) @build_config_overrides = args[:build_config_overrides] if args.key?(:build_config_overrides) @service_config_overrides = args[:service_config_overrides] if args.key?(:service_config_overrides) @trigger_service_account = args[:trigger_service_account] if args.key?(:trigger_service_account) end |