Class: Google::Apis::CloudfunctionsV2beta::SourceProvenance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudfunctions_v2beta/classes.rb,
lib/google/apis/cloudfunctions_v2beta/representations.rb,
lib/google/apis/cloudfunctions_v2beta/representations.rb

Overview

Provenance of the source. Ways to find the original source, or verify that some source was used for this build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceProvenance

Returns a new instance of SourceProvenance.



2084
2085
2086
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 2084

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#git_uriString

A copy of the build's source.git_uri, if exists, with any commits resolved. Corresponds to the JSON property gitUri

Returns:

  • (String)


2072
2073
2074
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 2072

def git_uri
  @git_uri
end

#resolved_repo_sourceGoogle::Apis::CloudfunctionsV2beta::RepoSource

Location of the source in a Google Cloud Source Repository. Corresponds to the JSON property resolvedRepoSource



2077
2078
2079
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 2077

def resolved_repo_source
  @resolved_repo_source
end

#resolved_storage_sourceGoogle::Apis::CloudfunctionsV2beta::StorageSource

Location of the source in an archive file in Google Cloud Storage. Corresponds to the JSON property resolvedStorageSource



2082
2083
2084
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 2082

def resolved_storage_source
  @resolved_storage_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2089
2090
2091
2092
2093
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 2089

def update!(**args)
  @git_uri = args[:git_uri] if args.key?(:git_uri)
  @resolved_repo_source = args[:resolved_repo_source] if args.key?(:resolved_repo_source)
  @resolved_storage_source = args[:resolved_storage_source] if args.key?(:resolved_storage_source)
end