Class: Google::Apis::CloudfunctionsV2beta::CloudFunctionsService

Inherits:
Google::Apis::Core::BaseService
  • Object
show all
Defined in:
lib/google/apis/cloudfunctions_v2beta/service.rb

Overview

Cloud Functions API

Manages lightweight user-provided functions executed in response to events.

Examples:

require 'google/apis/cloudfunctions_v2beta'

Cloudfunctions = Google::Apis::CloudfunctionsV2beta # Alias the module
service = Cloudfunctions::CloudFunctionsService.new

See Also:

Constant Summary collapse

DEFAULT_ENDPOINT_TEMPLATE =
"https://cloudfunctions.$UNIVERSE_DOMAIN$/"

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeCloudFunctionsService

Returns a new instance of CloudFunctionsService.



47
48
49
50
51
52
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 47

def initialize
  super(DEFAULT_ENDPOINT_TEMPLATE, '',
        client_name: 'google-apis-cloudfunctions_v2beta',
        client_version: Google::Apis::CloudfunctionsV2beta::GEM_VERSION)
  @batch_path = 'batch'
end

Instance Attribute Details

#keyString

Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.

Returns:

  • (String)

    API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.



40
41
42
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 40

def key
  @key
end

#quota_userString

Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

Returns:

  • (String)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.



45
46
47
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 45

def quota_user
  @quota_user
end

Instance Method Details

#abort_function_upgrade(name, abort_function_upgrade_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation

Aborts generation upgrade process for a function with the given name from the specified project. Deletes all 2nd Gen copy related configuration and resources which were created during the upgrade process.

Parameters:

  • name (String)

    Required. The name of the function for which upgrade should be aborted.

  • abort_function_upgrade_request_object (Google::Apis::CloudfunctionsV2beta::AbortFunctionUpgradeRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



124
125
126
127
128
129
130
131
132
133
134
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 124

def abort_function_upgrade(name, abort_function_upgrade_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v2beta/{+name}:abortFunctionUpgrade', options)
  command.request_representation = Google::Apis::CloudfunctionsV2beta::AbortFunctionUpgradeRequest::Representation
  command.request_object = abort_function_upgrade_request_object
  command.response_representation = Google::Apis::CloudfunctionsV2beta::Operation::Representation
  command.response_class = Google::Apis::CloudfunctionsV2beta::Operation
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#commit_function_upgrade(name, commit_function_upgrade_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation

Finalizes the upgrade after which function upgrade can not be rolled back. This is the last step of the multi step process to upgrade 1st Gen functions to 2nd Gen. Deletes all original 1st Gen related configuration and resources.

Parameters:

  • name (String)

    Required. The name of the function for which upgrade should be finalized.

  • commit_function_upgrade_request_object (Google::Apis::CloudfunctionsV2beta::CommitFunctionUpgradeRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



159
160
161
162
163
164
165
166
167
168
169
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 159

def commit_function_upgrade(name, commit_function_upgrade_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v2beta/{+name}:commitFunctionUpgrade', options)
  command.request_representation = Google::Apis::CloudfunctionsV2beta::CommitFunctionUpgradeRequest::Representation
  command.request_object = commit_function_upgrade_request_object
  command.response_representation = Google::Apis::CloudfunctionsV2beta::Operation::Representation
  command.response_class = Google::Apis::CloudfunctionsV2beta::Operation
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#commit_function_upgrade_as_gen2(name, commit_function_upgrade_as_gen2_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation

Commits a function upgrade from GCF Gen1 to GCF Gen2. This action deletes the Gen1 function, leaving the Gen2 function active and manageable by the GCFv2 API.

Parameters:

  • name (String)

    Required. The name of the function for which upgrade should be committed to Gen2.

  • commit_function_upgrade_as_gen2_request_object (Google::Apis::CloudfunctionsV2beta::CommitFunctionUpgradeAsGen2Request) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



195
196
197
198
199
200
201
202
203
204
205
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 195

def commit_function_upgrade_as_gen2(name, commit_function_upgrade_as_gen2_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v2beta/{+name}:commitFunctionUpgradeAsGen2', options)
  command.request_representation = Google::Apis::CloudfunctionsV2beta::CommitFunctionUpgradeAsGen2Request::Representation
  command.request_object = commit_function_upgrade_as_gen2_request_object
  command.response_representation = Google::Apis::CloudfunctionsV2beta::Operation::Representation
  command.response_class = Google::Apis::CloudfunctionsV2beta::Operation
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#create_project_location_function(parent, function_object = nil, function_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation

Creates a new function. If a function with the given name already exists in the specified project, the long running operation will return ALREADY_EXISTS error.

Parameters:

  • parent (String)

    Required. The project and location in which the function should be created, specified in the format projects/*/locations/*

  • function_object (Google::Apis::CloudfunctionsV2beta::Function) (defaults to: nil)
  • function_id (String) (defaults to: nil)

    The ID to use for the function, which will become the final component of the function's resource name. This value should be 4-63 characters, and valid characters are /a-z-/.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 235

def create_project_location_function(parent, function_object = nil, function_id: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v2beta/{+parent}/functions', options)
  command.request_representation = Google::Apis::CloudfunctionsV2beta::Function::Representation
  command.request_object = function_object
  command.response_representation = Google::Apis::CloudfunctionsV2beta::Operation::Representation
  command.response_class = Google::Apis::CloudfunctionsV2beta::Operation
  command.params['parent'] = parent unless parent.nil?
  command.query['functionId'] = function_id unless function_id.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_project_location_function(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation

Deletes a function with the given name from the specified project. If the given function is used by some trigger, the trigger will be updated to remove this function.

Parameters:

  • name (String)

    Required. The name of the function which should be deleted.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



270
271
272
273
274
275
276
277
278
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 270

def delete_project_location_function(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:delete, 'v2beta/{+name}', options)
  command.response_representation = Google::Apis::CloudfunctionsV2beta::Operation::Representation
  command.response_class = Google::Apis::CloudfunctionsV2beta::Operation
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#detach_function(name, detach_function_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation

Detaches 2nd Gen function to Cloud Run function.

Parameters:

  • name (String)

    Required. The name of the function for which should be detached.

  • detach_function_request_object (Google::Apis::CloudfunctionsV2beta::DetachFunctionRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



301
302
303
304
305
306
307
308
309
310
311
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 301

def detach_function(name, detach_function_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v2beta/{+name}:detachFunction', options)
  command.request_representation = Google::Apis::CloudfunctionsV2beta::DetachFunctionRequest::Representation
  command.request_object = detach_function_request_object
  command.response_representation = Google::Apis::CloudfunctionsV2beta::Operation::Representation
  command.response_class = Google::Apis::CloudfunctionsV2beta::Operation
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#generate_function_download_url(name, generate_download_url_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::GenerateDownloadUrlResponse

Returns a signed URL for downloading deployed function source code. The URL is only valid for a limited period and should be used within 30 minutes of generation. For more information about the signed URL usage see: https://cloud. google.com/storage/docs/access-control/signed-urls

Parameters:

  • name (String)

    Required. The name of function for which source code Google Cloud Storage signed URL should be generated.

  • generate_download_url_request_object (Google::Apis::CloudfunctionsV2beta::GenerateDownloadUrlRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



338
339
340
341
342
343
344
345
346
347
348
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 338

def generate_function_download_url(name, generate_download_url_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v2beta/{+name}:generateDownloadUrl', options)
  command.request_representation = Google::Apis::CloudfunctionsV2beta::GenerateDownloadUrlRequest::Representation
  command.request_object = generate_download_url_request_object
  command.response_representation = Google::Apis::CloudfunctionsV2beta::GenerateDownloadUrlResponse::Representation
  command.response_class = Google::Apis::CloudfunctionsV2beta::GenerateDownloadUrlResponse
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#generate_function_upload_url(parent, generate_upload_url_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::GenerateUploadUrlResponse

Returns a signed URL for uploading a function source code. For more information about the signed URL usage see: https://cloud.google.com/storage/ docs/access-control/signed-urls. Once the function source code upload is complete, the used signed URL should be provided in CreateFunction or UpdateFunction request as a reference to the function source code. When uploading source code to the generated signed URL, please follow these restrictions: * Source file type should be a zip file. * No credentials should be attached - the signed URLs provide access to the target bucket using internal service identity; if credentials were attached, the identity from the credentials would be used, but that identity does not have permissions to upload files to the URL. When making a HTTP PUT request, specify this header: * content-type: application/zip Do not specify this header: * Authorization: Bearer YOUR_TOKEN

Parameters:

  • parent (String)

    Required. The project and location in which the Google Cloud Storage signed URL should be generated, specified in the format projects/*/locations/*.

  • generate_upload_url_request_object (Google::Apis::CloudfunctionsV2beta::GenerateUploadUrlRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



384
385
386
387
388
389
390
391
392
393
394
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 384

def generate_function_upload_url(parent, generate_upload_url_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v2beta/{+parent}/functions:generateUploadUrl', options)
  command.request_representation = Google::Apis::CloudfunctionsV2beta::GenerateUploadUrlRequest::Representation
  command.request_object = generate_upload_url_request_object
  command.response_representation = Google::Apis::CloudfunctionsV2beta::GenerateUploadUrlResponse::Representation
  command.response_class = Google::Apis::CloudfunctionsV2beta::GenerateUploadUrlResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_location_function(name, revision: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Function

Returns a function with the given name from the requested project.

Parameters:

  • name (String)

    Required. The name of the function which details should be obtained.

  • revision (String) (defaults to: nil)

    Optional. The optional version of the 1st gen function whose details should be obtained. The version of a 1st gen function is an integer that starts from 1 and gets incremented on redeployments. GCF may keep historical configs for old versions of 1st gen function. This field can be specified to fetch the historical configs. This field is valid only for GCF 1st gen function.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



422
423
424
425
426
427
428
429
430
431
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 422

def get_project_location_function(name, revision: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v2beta/{+name}', options)
  command.response_representation = Google::Apis::CloudfunctionsV2beta::Function::Representation
  command.response_class = Google::Apis::CloudfunctionsV2beta::Function
  command.params['name'] = name unless name.nil?
  command.query['revision'] = revision unless revision.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_location_function_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Policy

Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.

Parameters:

  • resource (String)

    REQUIRED: The resource for which the policy is being requested. See Resource names for the appropriate value for this field.

  • options_requested_policy_version (Fixnum) (defaults to: nil)

    Optional. The maximum policy version that will be used to format the policy. Valid values are 0, 1, and 3. Requests specifying an invalid value will be rejected. Requests for policies with any conditional role bindings must specify version 3. Policies with no conditional role bindings may specify any valid value or leave the field unset. The policy in the response might use the policy version that you specified, or it might use a lower policy version. For example, if you specify version 3, but the policy has no conditional role bindings, the response uses version 1. To learn which resources support conditions in their IAM policies, see the IAM documentation.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



467
468
469
470
471
472
473
474
475
476
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 467

def get_project_location_function_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v2beta/{+resource}:getIamPolicy', options)
  command.response_representation = Google::Apis::CloudfunctionsV2beta::Policy::Representation
  command.response_class = Google::Apis::CloudfunctionsV2beta::Policy
  command.params['resource'] = resource unless resource.nil?
  command.query['options.requestedPolicyVersion'] = options_requested_policy_version unless options_requested_policy_version.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation

Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.

Parameters:

  • name (String)

    The name of the operation resource.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



778
779
780
781
782
783
784
785
786
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 778

def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v2beta/{+name}', options)
  command.response_representation = Google::Apis::CloudfunctionsV2beta::Operation::Representation
  command.response_class = Google::Apis::CloudfunctionsV2beta::Operation
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_project_location_functions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::ListFunctionsResponse

Returns a list of functions that belong to the requested project.

Parameters:

  • parent (String)

    Required. The project and location from which the function should be listed, specified in the format projects/*/locations/* If you want to list functions in all locations, use "-" in place of a location. When listing functions in all locations, if one or more location(s) are unreachable, the response will contain functions from all reachable locations along with the names of any unreachable locations.

  • filter (String) (defaults to: nil)

    The filter for Functions that match the filter expression, following the syntax outlined in https://google.aip.dev/160.

  • order_by (String) (defaults to: nil)

    The sorting order of the resources returned. Value should be a comma separated list of fields. The default sorting order is ascending. See https://google.aip. dev/132#ordering.

  • page_size (Fixnum) (defaults to: nil)

    Maximum number of functions to return per call. The largest allowed page_size is 1,000, if the page_size is omitted or specified as greater than 1,000 then it will be replaced as 1,000. The size of the list response can be less than specified when used with filters.

  • page_token (String) (defaults to: nil)

    The value returned by the last ListFunctionsResponse; indicates that this is a continuation of a prior ListFunctions call, and that the system should return the next page of data.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



519
520
521
522
523
524
525
526
527
528
529
530
531
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 519

def list_project_location_functions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v2beta/{+parent}/functions', options)
  command.response_representation = Google::Apis::CloudfunctionsV2beta::ListFunctionsResponse::Representation
  command.response_class = Google::Apis::CloudfunctionsV2beta::ListFunctionsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['orderBy'] = order_by unless order_by.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::ListOperationsResponse

Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns UNIMPLEMENTED.

Parameters:

  • name (String)

    The name of the operation's parent resource.

  • filter (String) (defaults to: nil)

    The standard list filter.

  • page_size (Fixnum) (defaults to: nil)

    The standard list page size.

  • page_token (String) (defaults to: nil)

    The standard list page token.

  • return_partial_success (Boolean) (defaults to: nil)

    When set to true, operations that are reachable are returned as normal, and those that are unreachable are returned in the ListOperationsResponse. unreachable field. This can only be true when reading across collections. For example, when parent is set to "projects/example/locations/-". This field is not supported by default and will result in an UNIMPLEMENTED error if set unless explicitly documented otherwise in service or product specific documentation.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



823
824
825
826
827
828
829
830
831
832
833
834
835
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 823

def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v2beta/{+name}/operations', options)
  command.response_representation = Google::Apis::CloudfunctionsV2beta::ListOperationsResponse::Representation
  command.response_class = Google::Apis::CloudfunctionsV2beta::ListOperationsResponse
  command.params['name'] = name unless name.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_project_location_runtimes(parent, filter: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::ListRuntimesResponse

Returns a list of runtimes that are supported for the requested project.

Parameters:

  • parent (String)

    Required. The project and location from which the runtimes should be listed, specified in the format projects/*/locations/*

  • filter (String) (defaults to: nil)

    The filter for Runtimes that match the filter expression, following the syntax outlined in https://google.aip.dev/160.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



861
862
863
864
865
866
867
868
869
870
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 861

def list_project_location_runtimes(parent, filter: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v2beta/{+parent}/runtimes', options)
  command.response_representation = Google::Apis::CloudfunctionsV2beta::ListRuntimesResponse::Representation
  command.response_class = Google::Apis::CloudfunctionsV2beta::ListRuntimesResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::ListLocationsResponse

Lists information about the supported locations for this service.

Parameters:

  • name (String)

    The resource that owns the locations collection, if applicable.

  • extra_location_types (Array<String>, String) (defaults to: nil)

    Optional. Do not use this field. It is unsupported and is ignored unless explicitly documented otherwise. This is primarily for internal usage.

  • filter (String) (defaults to: nil)

    A filter to narrow down results to a preferred subset. The filtering language accepts strings like "displayName=tokyo", and is documented in more detail in AIP-160.

  • page_size (Fixnum) (defaults to: nil)

    The maximum number of results to return. If not set, the service selects a default.

  • page_token (String) (defaults to: nil)

    A page token received from the next_page_token field in the response. Send that page token to receive the subsequent page.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 87

def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v2beta/{+name}/locations', options)
  command.response_representation = Google::Apis::CloudfunctionsV2beta::ListLocationsResponse::Representation
  command.response_class = Google::Apis::CloudfunctionsV2beta::ListLocationsResponse
  command.params['name'] = name unless name.nil?
  command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#patch_project_location_function(name, function_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation

Updates existing function.

Parameters:

  • name (String)

    A user-defined name of the function. Function names must be unique globally and match pattern projects/*/locations/*/functions/*

  • function_object (Google::Apis::CloudfunctionsV2beta::Function) (defaults to: nil)
  • update_mask (String) (defaults to: nil)

    The list of fields to be updated. If no field mask is provided, all fields will be updated.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



558
559
560
561
562
563
564
565
566
567
568
569
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 558

def patch_project_location_function(name, function_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:patch, 'v2beta/{+name}', options)
  command.request_representation = Google::Apis::CloudfunctionsV2beta::Function::Representation
  command.request_object = function_object
  command.response_representation = Google::Apis::CloudfunctionsV2beta::Operation::Representation
  command.response_class = Google::Apis::CloudfunctionsV2beta::Operation
  command.params['name'] = name unless name.nil?
  command.query['updateMask'] = update_mask unless update_mask.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#redirect_function_upgrade_traffic(name, redirect_function_upgrade_traffic_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation

Changes the traffic target of a function from the original 1st Gen function to the 2nd Gen copy. This is the second step of the multi step process to upgrade 1st Gen functions to 2nd Gen. After this operation, all new traffic will be served by 2nd Gen copy.

Parameters:

  • name (String)

    Required. The name of the function for which traffic target should be changed to 2nd Gen from 1st Gen.

  • redirect_function_upgrade_traffic_request_object (Google::Apis::CloudfunctionsV2beta::RedirectFunctionUpgradeTrafficRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



596
597
598
599
600
601
602
603
604
605
606
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 596

def redirect_function_upgrade_traffic(name, redirect_function_upgrade_traffic_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v2beta/{+name}:redirectFunctionUpgradeTraffic', options)
  command.request_representation = Google::Apis::CloudfunctionsV2beta::RedirectFunctionUpgradeTrafficRequest::Representation
  command.request_object = redirect_function_upgrade_traffic_request_object
  command.response_representation = Google::Apis::CloudfunctionsV2beta::Operation::Representation
  command.response_class = Google::Apis::CloudfunctionsV2beta::Operation
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#rollback_function_upgrade_traffic(name, rollback_function_upgrade_traffic_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation

Reverts the traffic target of a function from the 2nd Gen copy to the original 1st Gen function. After this operation, all new traffic would be served by the 1st Gen.

Parameters:

  • name (String)

    Required. The name of the function for which traffic target should be changed back to 1st Gen from 2nd Gen.

  • rollback_function_upgrade_traffic_request_object (Google::Apis::CloudfunctionsV2beta::RollbackFunctionUpgradeTrafficRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



632
633
634
635
636
637
638
639
640
641
642
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 632

def rollback_function_upgrade_traffic(name, rollback_function_upgrade_traffic_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v2beta/{+name}:rollbackFunctionUpgradeTraffic', options)
  command.request_representation = Google::Apis::CloudfunctionsV2beta::RollbackFunctionUpgradeTrafficRequest::Representation
  command.request_object = rollback_function_upgrade_traffic_request_object
  command.response_representation = Google::Apis::CloudfunctionsV2beta::Operation::Representation
  command.response_class = Google::Apis::CloudfunctionsV2beta::Operation
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#set_function_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Policy

Sets the access control policy on the specified resource. Replaces any existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.

Parameters:

  • resource (String)

    REQUIRED: The resource for which the policy is being specified. See Resource names for the appropriate value for this field.

  • set_iam_policy_request_object (Google::Apis::CloudfunctionsV2beta::SetIamPolicyRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



669
670
671
672
673
674
675
676
677
678
679
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 669

def set_function_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v2beta/{+resource}:setIamPolicy', options)
  command.request_representation = Google::Apis::CloudfunctionsV2beta::SetIamPolicyRequest::Representation
  command.request_object = set_iam_policy_request_object
  command.response_representation = Google::Apis::CloudfunctionsV2beta::Policy::Representation
  command.response_class = Google::Apis::CloudfunctionsV2beta::Policy
  command.params['resource'] = resource unless resource.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#setup_function_upgrade_config(name, setup_function_upgrade_config_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::Operation

Creates a 2nd Gen copy of the function configuration based on the 1st Gen function with the given name. This is the first step of the multi step process to upgrade 1st Gen functions to 2nd Gen. Only 2nd Gen configuration is setup as part of this request and traffic continues to be served by 1st Gen.

Parameters:

  • name (String)

    Required. The name of the function which should have configuration copied for upgrade.

  • setup_function_upgrade_config_request_object (Google::Apis::CloudfunctionsV2beta::SetupFunctionUpgradeConfigRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



706
707
708
709
710
711
712
713
714
715
716
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 706

def setup_function_upgrade_config(name, setup_function_upgrade_config_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v2beta/{+name}:setupFunctionUpgradeConfig', options)
  command.request_representation = Google::Apis::CloudfunctionsV2beta::SetupFunctionUpgradeConfigRequest::Representation
  command.request_object = setup_function_upgrade_config_request_object
  command.response_representation = Google::Apis::CloudfunctionsV2beta::Operation::Representation
  command.response_class = Google::Apis::CloudfunctionsV2beta::Operation
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#test_function_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudfunctionsV2beta::TestIamPermissionsResponse

Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error. Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may "fail open" without warning.

Parameters:

  • resource (String)

    REQUIRED: The resource for which the policy detail is being requested. See Resource names for the appropriate value for this field.

  • test_iam_permissions_request_object (Google::Apis::CloudfunctionsV2beta::TestIamPermissionsRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



745
746
747
748
749
750
751
752
753
754
755
# File 'lib/google/apis/cloudfunctions_v2beta/service.rb', line 745

def test_function_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v2beta/{+resource}:testIamPermissions', options)
  command.request_representation = Google::Apis::CloudfunctionsV2beta::TestIamPermissionsRequest::Representation
  command.request_object = test_iam_permissions_request_object
  command.response_representation = Google::Apis::CloudfunctionsV2beta::TestIamPermissionsResponse::Representation
  command.response_class = Google::Apis::CloudfunctionsV2beta::TestIamPermissionsResponse
  command.params['resource'] = resource unless resource.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end