Class: Google::Apis::CloudfunctionsV2beta::OperationMetadataV1
- Inherits:
-
Object
- Object
- Google::Apis::CloudfunctionsV2beta::OperationMetadataV1
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudfunctions_v2beta/classes.rb,
lib/google/apis/cloudfunctions_v2beta/representations.rb,
lib/google/apis/cloudfunctions_v2beta/representations.rb
Overview
Metadata describing an Operation
Instance Attribute Summary collapse
-
#build_id ⇒ String
The Cloud Build ID of the function created or updated by an API call.
-
#build_name ⇒ String
The Cloud Build Name of the function deployment.
-
#request ⇒ Hash<String,Object>
The original request that started the operation.
-
#source_token ⇒ String
An identifier for Firebase function sources.
-
#target ⇒ String
Target of the operation - for example
projects/project-1/locations/region-1/ functions/function-1Corresponds to the JSON propertytarget. -
#type ⇒ String
Type of operation.
-
#update_time ⇒ String
The last update timestamp of the operation.
-
#version_id ⇒ Fixnum
Version id of the function created or updated by an API call.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationMetadataV1
constructor
A new instance of OperationMetadataV1.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationMetadataV1
Returns a new instance of OperationMetadataV1.
1365 1366 1367 |
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 1365 def initialize(**args) update!(**args) end |
Instance Attribute Details
#build_id ⇒ String
The Cloud Build ID of the function created or updated by an API call. This
field is only populated for Create and Update operations.
Corresponds to the JSON property buildId
1324 1325 1326 |
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 1324 def build_id @build_id end |
#build_name ⇒ String
The Cloud Build Name of the function deployment. This field is only populated
for Create and Update operations. projects//locations//builds/.
Corresponds to the JSON property buildName
1330 1331 1332 |
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 1330 def build_name @build_name end |
#request ⇒ Hash<String,Object>
The original request that started the operation.
Corresponds to the JSON property request
1335 1336 1337 |
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 1335 def request @request end |
#source_token ⇒ String
An identifier for Firebase function sources. Disclaimer: This field is only
supported for Firebase function deployments.
Corresponds to the JSON property sourceToken
1341 1342 1343 |
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 1341 def source_token @source_token end |
#target ⇒ String
Target of the operation - for example projects/project-1/locations/region-1/
functions/function-1
Corresponds to the JSON property target
1347 1348 1349 |
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 1347 def target @target end |
#type ⇒ String
Type of operation.
Corresponds to the JSON property type
1352 1353 1354 |
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 1352 def type @type end |
#update_time ⇒ String
The last update timestamp of the operation.
Corresponds to the JSON property updateTime
1357 1358 1359 |
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 1357 def update_time @update_time end |
#version_id ⇒ Fixnum
Version id of the function created or updated by an API call. This field is
only populated for Create and Update operations.
Corresponds to the JSON property versionId
1363 1364 1365 |
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 1363 def version_id @version_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 |
# File 'lib/google/apis/cloudfunctions_v2beta/classes.rb', line 1370 def update!(**args) @build_id = args[:build_id] if args.key?(:build_id) @build_name = args[:build_name] if args.key?(:build_name) @request = args[:request] if args.key?(:request) @source_token = args[:source_token] if args.key?(:source_token) @target = args[:target] if args.key?(:target) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) @version_id = args[:version_id] if args.key?(:version_id) end |